@@ -1,14 +1,19 @@
+import os
 from datetime import date
 from typing import Optional
 
 from pydantic import Field, validator
 
 from algora.common.base import Base
+from algora.common.config import EnvironmentConfig
+
+
+config = EnvironmentConfig()
 
 
 class FredQuery(Base):
-    api_key: str
     series_id: str
+    api_key: str = Field(default=config.auth_config.fred_api_key, init=False)
     file_type: str = Field(default='json')
     observation_start: Optional[date] = None
     observation_end: Optional[date] = None
